#!/bin/sh

# Script to be run after restoring backup data
LOGGER=/usr/bin/logger

log () { $LOGGER $0 "$@"; }

log_and_exec () 
{ 
    log "$@";
    if [ x"$DEBUG" = x ];
    then
        "$@";
    else
        "$@" 2>&1 | $LOGGER;
    fi;
}

RESTORE_LIST="$*";
ACCOUNTSDIR=/home/user/.rtcom-accounts;
BACKUPDIR="/tmp/.rtcom";
BACKUPFILE="/tmp/rtcom.tar";
RING_FILE="ring.cfg";
RING_CONF="/var/lib/mission-control-5";

log "$0: started ($RESTORE_LIST)";
echo "$*" | grep -q "settings" || exit 0;

log "stopping mission-control";
log_and_exec /sbin/stop xsession/mission-control;

log "restoring non-libaccounts accounts+settings";
log_and_exec tar -C /tmp -xvf $BACKUPFILE
log_and_exec rm -rf $ACCOUNTSDIR;
log_and_exec mv $BACKUPDIR $ACCOUNTSDIR;

# ring account doesn't live here any more:
if [ -f "$ACCOUNTSDIR/$RING_FILE" ];
then
    log "restoring ring account settings";
    log_and_exec mv -f $ACCOUNTSDIR/$RING_FILE $RING_CONF/$RING_FILE;
    log_and_exec chmod 0600 $RING_CONF/$RING_FILE;
    log_and_exec chown user:operator $RING_CONF/$RING_FILE;
fi;

log "restoring file permissions";
# make sure the permissions and ownership of the restored files is correct:
find $ACCOUNTSDIR -type d | while read TARGET;
do
    log_and_exec chown user:users "$TARGET";
    log_and_exec chmod 0700 "$TARGET";
done;

find $ACCOUNTSDIR -type f | while read TARGET
do
    log_and_exec chown user:users "$TARGET";
    log_and_exec chmod 0600 "$TARGET";
done;

log_and_exec sync
log "finished"
